@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: exception.cc 474 2007-12-28 11:06:21Z murrayc $ */
+/* $Id: exception.cc 270 2006-04-14 10:13:46Z  $ */
 
 /* exception.cc
  *
@@ -20,10 +20,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-//#include <glib/gtestutils.h> //For g_assert() in glib >= 2.15.0
-//#include <glib/gmessages.h> //For g_assert() in glib < 2.15.0
-#include <glib.h> //For g_assert() in all versions of glib.
-
+#include <glib/gmessages.h>
 #include <glibmm/exception.h>
 
 
